@@ -4,27 +4,31 @@ Python interface for the Codex CLI.
 
 Usage:
     from codex import run_exec
-    output = run_exec("explain this codebase to me")
+    events = run_exec("explain this codebase to me")
 """
 
 from .api import (
     CodexClient,
     CodexError,
-    CodexNotFoundError,
-    CodexProcessError,
-    find_binary,
+    CodexNativeError,
+    Conversation,
     run_exec,
 )
+from .config import CodexConfig
+from .event import Event
+from .protocol.types import EventMsg
 
 __all__ = [
     "__version__",
     "CodexError",
-    "CodexNotFoundError",
-    "CodexProcessError",
+    "CodexNativeError",
     "CodexClient",
-    "find_binary",
+    "Conversation",
     "run_exec",
+    "Event",
+    "EventMsg",
+    "CodexConfig",
 ]
 
 # Managed by Hatch via pyproject.toml [tool.hatch.version]
-__version__ = "0.1.1"
+__version__ = "0.2.0"
